import { Component, OnInit } from '@angular/core';
import { Organization, OrganizationRO } from 'src/app/models/organization.model';
import { OrganizationService } from 'src/app/services/organization.service';
import { Subscription } from 'rxjs';
import { PaginatorOptions } from 'src/app/models/paginator-options.model';

@Component({
  selector: 'app-organizations',
  templateUrl: './organizations.component.html',
  styleUrls: ['./organizations.component.scss'],
})
export class OrganizationsComponent implements OnInit {

  organizations: Organization[];
  searchChangeSub: Subscription;

  // Paginator options
  paginator: PaginatorOptions;

  sortValue: string;

  totalElement: number;
  pageSize = 10;
  pageSizeOptions = [5, 10, 25, 100];
  filters = {
    name: '',
  };
  where = {};

  constructor(
    private organizationsService: OrganizationService,
  ) {
    this.paginator = {
      pageIndex: this.organizationsService.pageNumber,
      length: 0,
      limit: this.organizationsService.limit,
      pageSizeOptions: [5, 10, 20],
    };
  }

  ngOnInit(): void {
    this.organizationsService.sortOptions = {
      value: 'name',
      order: 'asc',
    };
    this.search();

    this.searchChangeSub = this.organizationsService.searchChange$.subscribe(
      () => {
        this.search();
      },
    );
  }

  private search() {
    this.organizationsService.getOrganizations()
      .subscribe((items: OrganizationRO) => {
        this.organizations = items.organizations;
        this.totalElement = items.totalCount;

        this.paginator.limit = this.organizationsService.limit;
        this.paginator.pageIndex = this.organizationsService.pageNumber;
        this.paginator.length = items.totalCount;
      });
  }

  // When pagination is changed by user, we update datasetList with new pagination options
  changePagination(pageIndex) {
    this.organizationsService.paginationChanged(this.paginator.limit, pageIndex);
  }

  changePageSize(pageSize) {
    this.organizationsService.paginationChanged(pageSize, 1);
  }

  sortBy(key: string) {
    if (this.organizationsService.sortOptions.value === key) {
      this.organizationsService.reverseSortOrder();
    } else {
      this.organizationsService.sortOptions.value = key;
      this.organizationsService.sortOptions.order = 'asc';
    }
    this.search();
  }

  get sortOptions() {
    return this.organizationsService.sortOptions;
  }

  displayDeletePopup(organizationId) {
    const pop = confirm('Etes vous sûr de vouloir supprimer cette organisation ?');
    if (pop) {
      this.organizationsService.delete(organizationId).subscribe(() => {
        this.organizationsService.pageNumber = 1;
        this.search();
      });
    }
  }
}
